#
# spec file for package ansifilter
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Pascal Bleser.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without gui
Name:           ansifilter
Version:        2.13
Release:        lp152.2.9
Summary:        ANSI Terminal Escape Code Converter
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
Url:            http://www.andre-simon.de/
Source:         http://www.andre-simon.de/zip/ansifilter-%{version}.tar.bz2
Source2:        http://www.andre-simon.de/zip/ansifilter-%{version}.tar.bz2.asc
Source99:       ansifilter.keyring
BuildRequires:  gcc-c++

%description
Ansifilter handles text files containing ANSI terminal escape codes.
The command sequences may be stripped or be interpreted to generate formatted
output (HTML, RTF, TeX, LaTeX, BBCode).

%if %{with gui}
%package gui
Summary:        ANSI Terminal Escape Code Converter - Qt GUI
Group:          Development/Tools/Other
BuildRequires:  libqt5-qtbase-devel
Requires:       %{name} = %{version}
%if 0%{?suse_version} < 1330
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
%endif

%description gui
This package provides a Qt Graphical User Interface to run %{name}.
%endif

%prep
%setup -q
%if %{with gui}
# Remove pre-configured files which may cause errors with Leap 42.x.
rm -v src/qt-gui/moc_*.cpp
rm -v src/qt-gui/Makefile*
%endif

%build
make \
  CFLAGS="%{optflags} -fPIC" \
  CXXFLAGS="%{optflags} -std=c++11 -fPIC" \
  QMAKE="qmake-qt5" \
  all \
%if %{with gui}
  all-gui \
%endif
  %{?_smp_mflags}

%install
make \
  DESTDIR=%{buildroot} \
  doc_dir="%{_docdir}/%{name}" \
  install \
%if %{with gui}
  install-gui
%endif

rm %{buildroot}%{_docdir}/%{name}/INSTALL

%if %{with gui} && 0%{?suse_version} < 1330
%post gui
%desktop_database_post

%postun gui
%desktop_database_postun
%endif

%files
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/COPYING
%{_docdir}/%{name}/ChangeLog.adoc
%{_docdir}/%{name}/README.adoc
%{_bindir}/ansifilter
%{_mandir}/man1/ansifilter.1%{ext_man}

%if %{with gui}
%files gui
%{_bindir}/ansifilter-gui
%{_datadir}/applications/ansifilter.desktop
%{_datadir}/pixmaps/ansifilter.xpm
%endif

%changelog
* Fri Dec 14 2018 antoine.belvire@opensuse.org
- Update to version 2.13:
  * Line numbers do not trigger default style span in HTML
    (gl#saalen/ansifilter#19).
  * Fixed line numbering in batch mode.
  * CLI: Added --derived-styles option for HTML output
    (gl#saalen/ansifilter#11).
  * CLI: Added "self" argument to --anchors to generate
    self-referencing anchors.
- Changes from version 2.12:
  * Fixed -w char count if line contains escape sequences.
  * GUI: Added stylesheet input filed.
* Sun Oct 14 2018 antoine.belvire@opensuse.org
- Update to version 2.11:
  * Fixed parsing of "7" and "8" sequences
    (gl#saalen/ansifilter#16).
  * Added --ignore-clear option.
  * Converted README and ChangeLog to AsciiDoc
* Sat Jul  7 2018 antoine.belvire@opensuse.org
- Minor spec file cleanups.
* Wed Mar  7 2018 antoine.belvire@opensuse.org
- Update to 2.10:
  * Fix parsing of "K" sequence.
  * Fix memory leak in BIN parser.
- Ran spec-cleaner, use SPDX-3.0 format for license.
* Wed Nov 29 2017 antoine.belvire@opensuse.org
- Update to 2.9:
  * Fix parsing of "(B" reset sequence.
  * CLI: Add --no-version-info option.
  * GUI: Layout adjustments.
- Remove desktop file from sources (now included in upstream
  tarball).
* Sun Aug  6 2017 antoine.belvire@opensuse.org
- Update to 2.8:
  * Fix reading from stdin.
* Sat Aug  5 2017 antoine.belvire@opensuse.org
- Update to 2.7:
  * Fix processing of very small input files.
  * Add -fPIC to CXXFLAGS in src/makefile (no impact for openSUSE
    as default CXXFLAGS were already overriden with "%%%%{optflags}
  - fPIC" in spec file).
* Sun Jul 30 2017 antoine.belvire@opensuse.org
- Update to 2.6:
  * Add support for Tundra 24bit ANSI art (--art-tundra option).
  * Fix Pango output.
  * Add EXTRA_CXXFLAGS in src/makefile.
- Fix rpmlint warnings:
  * Add conditional in order not to call desktop_database_post(un)
    macros on Tumbleweed, as it's now handled by RPM filetriggers.
* Mon Jul  3 2017 antoine.belvire@opensuse.org
- Update to 2.5:
  * CLI: Add --no-trailing-nl option.
  * CLI: Add support for environment variable ANSIFILTER_OPTIONS.
- Changes from 2.4:
  * Fix crash reading irregular escape codes.
- Clean spec file.
- Update GPG public key (key had expired).
* Mon Sep 26 2016 antoine.belvire@opensuse.org
- Update to 2.3:
  * Add support for true color escape codes
* Sat Sep 17 2016 antoine.belvire@opensuse.org
- Update to 2.2:
  * A lot of changes happened since 1.7. Please refer to
    /usr/share/doc/packages/ansifilter/ChangeLog
  * Build with Qt 5 instead of Qt 4
- Drop ansifilter-compiler_flags.patch: this can be handled in
  %%%%build with environment variables.
- Add signature verification:
  * Add ansifilter.keyring (ansifilter's main developer Andre Simon
    public key)
  * Add ansifilter-2.2.tar.bz2.asc
- Clean spec file:
  * Remove obsolete conditional for openSUSE < 10.3
  * Simplify build requirements, move GUI specific dependencies
    to GUI subpackage
  * Clean with spec-cleaner
* Thu Nov 14 2013 cfarrell@suse.com
- license update: GPL-3.0+
  No indication that the package is GPL-3.0 (i.e. only). Also, include the
  COPYING file in the %%doc section of the package
* Tue Oct 29 2013 pth@suse.de
- Fix options passed to make.
- Add copyright to spec file.
* Mon Oct 28 2013 pth@suse.de
- Reorder compiler flags and use CXX and CXXFLAGS instead of
  CC and CFLAGS.
* Thu Jun 13 2013 pth@suse.de
- Update to 1.7:
  * add --wrap option to wrap long lines
  * fix tab output in plain text mode
- Fix license specification.
- Regenerate moc_mydialog.cpp to cater for changing Qt versions.
- Pass RPM_OPT_FLAGS to compiler and do not use processor specific
  flags (-march -mtune):
  ansifilter-compiler_flags.patch
* Thu Mar 31 2011 pascal.bleser@opensuse.org
- fix license: it's GPLv3, not GPLv2
- update to 1.6:
  * fixed tab output
  * added support for aixterm codes
  * added bbcode output
  * brightened default colours
- changes from 1.5:
  * fixed parsing of grep escape sequences
- changes from 1.4:
  * fixed parsing of xterm escape sequences
* Fri Jul 24 2009 pascal.bleser@opensuse.org
- new package
